#!/usr/bin/python3

import pygame


class Page:
    """
    Represents a "page". Can be used similar to a browser tab.
    To use this properly, you have to overwrite this class.
    """

    def __init__(
            self,
            app: any=None,
            surface: pygame.Surface=None,
            main_container: "Container"=None,
    ):
        """
        :param app: Can be any class. This has no builtin functionality,
            but this can be useful if you want to access something in your main class from a widget or something else.
        :param surface: If you dont want to directly draw a container's surface onto the screen,
            you can also draw your own surface.
        """

        self.app = app
        self.surface = surface
        self.main_container = main_container

    def draw(self, surface: pygame.Surface) -> None:
        """
        Draws the main container on the given surface.

        :param pygame.Surface surface: The surface to draw on.
        """

        if not self.surface is None:
            surface.blit(self.surface, (0, 0))

        if not self.main_container is None:
            self.main_container.draw(surface)

    def update(self) -> None:
        """
        Updates the main container.
        """

        if not self.main_container is None:
            self.main_container.update()

